@@ -6,6 +6,12 @@
  *
  * This file is placed under the LGPL.  Please see the file COPYING for more
  * details.
+ *
+ * SPDX-License-Identifier: LGPL-2.1
+ *
+ *
+ * Usage:
+ *   module_raw waveshare vid_pid=<vendorID>:<productID> len=<raw_data_len>
  */
 
 #include <stdlib.h>
@@ -54,7 +60,7 @@ static int waveshare_read(struct tslib_module_info *inf, struct ts_sample *samp,
 				"waveshare: searching for device using hidraw...\n");
 #endif
 			for (cnt = 0; cnt < HIDRAW_MAX_DEVICES; cnt++) {
-				snprintf(name_buf, sizeof(buf),
+				snprintf(name_buf, sizeof(name_buf),
 					 "/dev/hidraw%d", cnt);
 #ifdef DEBUG
 				fprintf(stderr,
@@ -87,15 +93,14 @@ static int waveshare_read(struct tslib_module_info *inf, struct ts_sample *samp,
 
 				if (i->vendor == info.vendor &&
 				    i->product == info.product) {
-					if (ts->fd > 0)
 					close(ts->fd);
 
 					ts->fd = ts_tmp->fd;
-					free(ts_tmp);
 					found = 1;
 #ifdef DEBUG
 					fprintf(stderr, "  correct device\n");
 #endif
+					ts_close(ts_tmp);
 					break;
 				}
 
