@@ -86,6 +86,10 @@ struct tsdev *ts_open(const char *name, int nonblock)
 
 	memset(ts, 0, sizeof(struct tsdev));
 
+	ts->eventpath = strdup(name);
+	if (!ts->eventpath)
+		goto free;
+
 	if (ts_open_restricted) {
 		ts->fd = ts_open_restricted(name, flags, NULL);
 		if (ts->fd == -1)
@@ -113,6 +117,9 @@ struct tsdev *ts_open(const char *name, int nonblock)
 	return ts;
 
 free:
+	if (ts->eventpath)
+		free(ts->eventpath);
+
 	free(ts);
 	return NULL;
 }
