@@ -40,7 +40,7 @@ static struct fb_fix_screeninfo fix;
 static struct fb_var_screeninfo var;
 static unsigned char *fbuffer;
 static unsigned char **line_addr;
-static int32_t fb_fd = 0;
+static int32_t fb_fd;
 static int32_t bytes_per_pixel;
 static uint32_t transp_mask;
 static uint32_t colormap[256];
@@ -49,8 +49,8 @@ int8_t rotation;
 
 static char *defaultfbdevice = "/dev/fb0";
 static char *defaultconsoledevice = "/dev/tty";
-static char *fbdevice = NULL;
-static char *consoledevice = NULL;
+static char *fbdevice;
+static char *consoledevice;
 
 #define VTNAME_LEN 128
 
@@ -61,18 +61,18 @@ int open_framebuffer(void)
 	int32_t fd, nr;
 	uint32_t y, addr;
 
-	if ((fbdevice = getenv ("TSLIB_FBDEVICE")) == NULL)
+	if ((fbdevice = getenv("TSLIB_FBDEVICE")) == NULL)
 		fbdevice = defaultfbdevice;
 
-	if ((consoledevice = getenv ("TSLIB_CONSOLEDEVICE")) == NULL)
+	if ((consoledevice = getenv("TSLIB_CONSOLEDEVICE")) == NULL)
 		consoledevice = defaultconsoledevice;
 
-	if (strcmp (consoledevice, "none") != 0) {
+	if (strcmp(consoledevice, "none") != 0) {
 		if (strlen(consoledevice) >= VTNAME_LEN)
 			return -1;
 
-		sprintf (vtname,"%s%d", consoledevice, 1);
-		fd = open (vtname, O_WRONLY);
+		sprintf(vtname, "%s%d", consoledevice, 1);
+		fd = open(vtname, O_WRONLY);
 		if (fd < 0) {
 			perror("open consoledevice");
 			return -1;
@@ -146,7 +146,12 @@ int open_framebuffer(void)
 		yres = var.yres;
 	}
 
-	fbuffer = mmap(NULL, fix.smem_len, PROT_READ | PROT_WRITE, MAP_FILE | MAP_SHARED, fb_fd, 0);
+	fbuffer = mmap(NULL,
+		       fix.smem_len,
+		       PROT_READ | PROT_WRITE, MAP_FILE | MAP_SHARED,
+		       fb_fd,
+		       0);
+
 	if (fbuffer == (unsigned char *)-1) {
 		perror("mmap framebuffer");
 		close(fb_fd);
@@ -157,10 +162,10 @@ int open_framebuffer(void)
 	bytes_per_pixel = (var.bits_per_pixel + 7) / 8;
 	transp_mask = ((1 << var.transp.length) - 1) <<
 		var.transp.offset; /* transp.length unlikely > 32 */
-	line_addr = malloc (sizeof (*line_addr) * var.yres_virtual);
+	line_addr = malloc(sizeof(*line_addr) * var.yres_virtual);
 	addr = 0;
 	for (y = 0; y < var.yres_virtual; y++, addr += fix.line_length)
-		line_addr [y] = fbuffer + addr;
+		line_addr[y] = fbuffer + addr;
 
 	return 0;
 }
@@ -171,7 +176,7 @@ void close_framebuffer(void)
 	munmap(fbuffer, fix.smem_len);
 	close(fb_fd);
 
-	if(strcmp(consoledevice,"none")!=0) {
+	if (strcmp(consoledevice, "none") != 0) {
 		if (ioctl(con_fd, KDSETMODE, KD_TEXT) < 0)
 			perror("KDSETMODE");
 
@@ -182,7 +187,7 @@ void close_framebuffer(void)
 		close(con_fd);
 	}
 
-	free (line_addr);
+	free(line_addr);
 
 	xres = 0;
 	yres = 0;
@@ -191,52 +196,54 @@ void close_framebuffer(void)
 
 void put_cross(int32_t x, int32_t y, uint32_t colidx)
 {
-	line (x - 10, y, x - 2, y, colidx);
-	line (x + 2, y, x + 10, y, colidx);
-	line (x, y - 10, x, y - 2, colidx);
-	line (x, y + 2, x, y + 10, colidx);
+	line(x - 10, y, x - 2, y, colidx);
+	line(x + 2, y, x + 10, y, colidx);
+	line(x, y - 10, x, y - 2, colidx);
+	line(x, y + 2, x, y + 10, colidx);
 
 #if 1
-	line (x - 6, y - 9, x - 9, y - 9, colidx + 1);
-	line (x - 9, y - 8, x - 9, y - 6, colidx + 1);
-	line (x - 9, y + 6, x - 9, y + 9, colidx + 1);
-	line (x - 8, y + 9, x - 6, y + 9, colidx + 1);
-	line (x + 6, y + 9, x + 9, y + 9, colidx + 1);
-	line (x + 9, y + 8, x + 9, y + 6, colidx + 1);
-	line (x + 9, y - 6, x + 9, y - 9, colidx + 1);
-	line (x + 8, y - 9, x + 6, y - 9, colidx + 1);
+	line(x - 6, y - 9, x - 9, y - 9, colidx + 1);
+	line(x - 9, y - 8, x - 9, y - 6, colidx + 1);
+	line(x - 9, y + 6, x - 9, y + 9, colidx + 1);
+	line(x - 8, y + 9, x - 6, y + 9, colidx + 1);
+	line(x + 6, y + 9, x + 9, y + 9, colidx + 1);
+	line(x + 9, y + 8, x + 9, y + 6, colidx + 1);
+	line(x + 9, y - 6, x + 9, y - 9, colidx + 1);
+	line(x + 8, y - 9, x + 6, y - 9, colidx + 1);
 #else
-	line (x - 7, y - 7, x - 4, y - 4, colidx + 1);
-	line (x - 7, y + 7, x - 4, y + 4, colidx + 1);
-	line (x + 4, y - 4, x + 7, y - 7, colidx + 1);
-	line (x + 4, y + 4, x + 7, y + 7, colidx + 1);
+	line(x - 7, y - 7, x - 4, y - 4, colidx + 1);
+	line(x - 7, y + 7, x - 4, y + 4, colidx + 1);
+	line(x + 4, y - 4, x + 7, y - 7, colidx + 1);
+	line(x + 4, y + 4, x + 7, y + 7, colidx + 1);
 #endif
 }
 
 static void put_char(int32_t x, int32_t y, int32_t c, int32_t colidx)
 {
-	int32_t i,j,bits;
+	int32_t i, j, bits;
 
 	for (i = 0; i < font_vga_8x8.height; i++) {
-		bits = font_vga_8x8.data [font_vga_8x8.height * c + i];
+		bits = font_vga_8x8.data[font_vga_8x8.height * c + i];
 		for (j = 0; j < font_vga_8x8.width; j++, bits <<= 1)
 			if (bits & 0x80)
-				pixel (x + j, y + i, colidx);
+				pixel(x + j, y + i, colidx);
 	}
 }
 
 void put_string(int32_t x, int32_t y, char *s, uint32_t colidx)
 {
 	int32_t i;
+
 	for (i = 0; *s; i++, x += font_vga_8x8.width, s++)
 		put_char (x, y, *s, colidx);
 }
 
 void put_string_center(int32_t x, int32_t y, char *s, uint32_t colidx)
 {
-	size_t sl = strlen (s);
-        put_string (x - (sl / 2) * font_vga_8x8.width,
-                    y - font_vga_8x8.height / 2, s, colidx);
+	size_t sl = strlen(s);
+
+	put_string(x - (sl / 2) * font_vga_8x8.width,
+		   y - font_vga_8x8.height / 2, s, colidx);
 }
 
 void setcolor(uint32_t colidx, uint32_t value)
@@ -247,8 +254,8 @@ void setcolor(uint32_t colidx, uint32_t value)
 
 	if (colidx > 255) {
 #ifdef DEBUG
-		fprintf (stderr, "WARNING: color index = %u, must be <256\n",
-			 colidx);
+		fprintf(stderr, "WARNING: color index = %u, must be <256\n",
+			colidx);
 #endif
 		return;
 	}
@@ -267,8 +274,8 @@ void setcolor(uint32_t colidx, uint32_t value)
 		cmap.blue = &blue;
 		cmap.transp = NULL;
 
-        	if (ioctl (fb_fd, FBIOPUTCMAP, &cmap) < 0)
-        	        perror("ioctl FBIOPUTCMAP");
+		if (ioctl(fb_fd, FBIOPUTCMAP, &cmap) < 0)
+			perror("ioctl FBIOPUTCMAP");
 		break;
 	case 2:
 	case 3:
@@ -277,10 +284,10 @@ void setcolor(uint32_t colidx, uint32_t value)
 		green = (value >> 8) & 0xff;
 		blue = value & 0xff;
 		res = ((red >> (8 - var.red.length)) << var.red.offset) |
-                      ((green >> (8 - var.green.length)) << var.green.offset) |
-                      ((blue >> (8 - var.blue.length)) << var.blue.offset);
+		      ((green >> (8 - var.green.length)) << var.green.offset) |
+		      ((blue >> (8 - var.blue.length)) << var.blue.offset);
 	}
-        colormap [colidx] = res;
+	colormap[colidx] = res;
 }
 
 static void __pixel_loc(int32_t x, int32_t y, union multiptr *loc)
@@ -302,9 +309,9 @@ static void __pixel_loc(int32_t x, int32_t y, union multiptr *loc)
 	}
 }
 
-static inline void __setpixel (union multiptr loc, uint32_t xormode, uint32_t color)
+static inline void __setpixel(union multiptr loc, uint32_t xormode, uint32_t color)
 {
-	switch(bytes_per_pixel) {
+	switch (bytes_per_pixel) {
 	case 1:
 	default:
 		if (xormode)
@@ -342,7 +349,7 @@ static inline void __setpixel (union multiptr loc, uint32_t xormode, uint32_t co
 	}
 }
 
-void pixel (int32_t x, int32_t y, uint32_t colidx)
+void pixel(int32_t x, int32_t y, uint32_t colidx)
 {
 	uint32_t xormode;
 	union multiptr loc;
@@ -356,23 +363,23 @@ void pixel (int32_t x, int32_t y, uint32_t colidx)
 
 	if (colidx > 255) {
 #ifdef DEBUG
-		fprintf (stderr, "WARNING: color value = %u, must be <256\n",
-			 colidx);
+		fprintf(stderr, "WARNING: color value = %u, must be <256\n",
+			colidx);
 #endif
 		return;
 	}
 
 	__pixel_loc(x, y, &loc);
-	__setpixel (loc, xormode, colormap [colidx]);
+	__setpixel(loc, xormode, colormap[colidx]);
 }
 
-void line (int32_t x1, int32_t y1, int32_t x2, int32_t y2, uint32_t colidx)
+void line(int32_t x1, int32_t y1, int32_t x2, int32_t y2, uint32_t colidx)
 {
 	int32_t tmp;
 	int32_t dx = x2 - x1;
 	int32_t dy = y2 - y1;
 
-	if (abs (dx) < abs (dy)) {
+	if (abs(dx) < abs(dy)) {
 		if (y1 > y2) {
 			tmp = x1; x1 = x2; x2 = tmp;
 			tmp = y1; y1 = y2; y2 = tmp;
@@ -382,7 +389,7 @@ void line (int32_t x1, int32_t y1, int32_t x2, int32_t y2, uint32_t colidx)
 		/* dy is apriori >0 */
 		dx = (dx << 16) / dy;
 		while (y1 <= y2) {
-			pixel (x1 >> 16, y1, colidx);
+			pixel(x1 >> 16, y1, colidx);
 			x1 += dx;
 			y1++;
 		}
@@ -395,22 +402,22 @@ void line (int32_t x1, int32_t y1, int32_t x2, int32_t y2, uint32_t colidx)
 		y1 <<= 16;
 		dy = dx ? (dy << 16) / dx : 0;
 		while (x1 <= x2) {
-			pixel (x1, y1 >> 16, colidx);
+			pixel(x1, y1 >> 16, colidx);
 			y1 += dy;
 			x1++;
 		}
 	}
 }
 
-void rect (int32_t x1, int32_t y1, int32_t x2, int32_t y2, uint32_t colidx)
+void rect(int32_t x1, int32_t y1, int32_t x2, int32_t y2, uint32_t colidx)
 {
-	line (x1, y1, x2, y1, colidx);
-	line (x2, y1+1, x2, y2-1, colidx);
-	line (x2, y2, x1, y2, colidx);
-	line (x1, y2-1, x1, y1+1, colidx);
+	line(x1, y1, x2, y1, colidx);
+	line(x2, y1+1, x2, y2-1, colidx);
+	line(x2, y2, x1, y2, colidx);
+	line(x1, y2-1, x1, y1+1, colidx);
 }
 
-void fillrect (int32_t x1, int32_t y1, int32_t x2, int32_t y2, uint32_t colidx)
+void fillrect(int32_t x1, int32_t y1, int32_t x2, int32_t y2, uint32_t colidx)
 {
 	int32_t tmp;
 	uint32_t xormode;
@@ -448,13 +455,13 @@ void fillrect (int32_t x1, int32_t y1, int32_t x2, int32_t y2, uint32_t colidx)
 
 	if (colidx > 255) {
 #ifdef DEBUG
-		fprintf (stderr, "WARNING: color value = %u, must be <256\n",
-			 colidx);
+		fprintf(stderr, "WARNING: color value = %u, must be <256\n",
+			colidx);
 #endif
 		return;
 	}
 
-	colidx = colormap [colidx];
+	colidx = colormap[colidx];
 
 	for (; y1 <= y2; y1++) {
 		for (tmp = x1; tmp <= x2; tmp++) {
