@@ -6,6 +6,8 @@
  * This file is placed under the GPL.  Please see the file
  * COPYING for more details.
  *
+ * SPDX-License-Identifier: GPL-2.0+
+ *
  *
  * Graphical touchscreen calibration tool. This writes the configuration
  * file used by tslib's "linear" filter plugin module to transform the
@@ -105,11 +107,8 @@ static void help(void)
 {
 	struct ts_lib_version_data *ver = ts_libversion();
 
-	printf("                 _       _ _ _\n");
-	printf("                | |_ ___| (_) |__\n");
-	printf("                | __/ __| | | '_ \\\n");
-	printf("                | |_\\__ \\ | | |_) |\n");
-	printf("                 \\__|___/_|_|_.__/\n\n");
+	print_ascii_logo();
+
 	printf("tslib %s / libts ABI version %d (0x%06X)\n",
 		ver->package_version, ver->version_num >> 16, ver->version_num);
 	printf("\n");
