@@ -22,14 +22,13 @@
 #include "fbutils.h"
 #include "testutils.h"
 
-static int palette [] =
-{
+static int palette[] = {
 	0x000000, 0xffe080, 0xffffff, 0xe0c0a0, 0x304050, 0x80b8c0
 };
 #define NR_COLORS (sizeof (palette) / sizeof (palette [0]))
 
 #define NR_BUTTONS 3
-static struct ts_button buttons [NR_BUTTONS];
+static struct ts_button buttons[NR_BUTTONS];
 
 static void sig(int sig)
 {
@@ -44,12 +43,13 @@ static void refresh_screen(void)
 {
 	int i;
 
-	fillrect (0, 0, xres - 1, yres - 1, 0);
-	put_string_center (xres/2, yres/4,   "Touchscreen test program", 1);
-	put_string_center (xres/2, yres/4+20,"Touch screen to move crosshair", 2);
+	fillrect(0, 0, xres - 1, yres - 1, 0);
+	put_string_center(xres / 2, yres / 4, "Touchscreen test program", 1);
+	put_string_center(xres / 2, yres / 4 + 20,
+			  "Touch screen to move crosshair", 2);
 
 	for (i = 0; i < NR_BUTTONS; i++)
-		button_draw (&buttons [i]);
+		button_draw(&buttons[i]);
 }
 
 static void help(void)
@@ -118,6 +118,7 @@ int main(int argc, char **argv)
 
 		if (errno) {
 			char str[9];
+
 			sprintf(str, "option ?");
 			str[7] = c & 0xff;
 			perror(str);
@@ -136,25 +137,25 @@ int main(int argc, char **argv)
 		exit(1);
 	}
 
-	x = xres/2;
-	y = yres/2;
+	x = xres / 2;
+	y = yres / 2;
 
 	for (i = 0; i < NR_COLORS; i++)
-		setcolor (i, palette [i]);
+		setcolor(i, palette[i]);
 
 	/* Initialize buttons */
-	memset (&buttons, 0, sizeof (buttons));
-	buttons [0].w = buttons [1].w = buttons [2].w = xres / 4;
-	buttons [0].h = buttons [1].h = buttons [2].h = 20;
-	buttons [0].x = 0;
-	buttons [1].x = (3 * xres) / 8;
-	buttons [2].x = (3 * xres) / 4;
-	buttons [0].y = buttons [1].y = buttons [2].y = 10;
-	buttons [0].text = "Drag";
-	buttons [1].text = "Draw";
-	buttons [2].text = "Quit";
+	memset(&buttons, 0, sizeof(buttons));
+	buttons[0].w = buttons[1].w = buttons[2].w = xres / 4;
+	buttons[0].h = buttons[1].h = buttons[2].h = 20;
+	buttons[0].x = 0;
+	buttons[1].x = (3 * xres) / 8;
+	buttons[2].x = (3 * xres) / 4;
+	buttons[0].y = buttons[1].y = buttons[2].y = 10;
+	buttons[0].text = "Drag";
+	buttons[1].text = "Draw";
+	buttons[2].text = "Quit";
 
-	refresh_screen ();
+	refresh_screen();
 
 	while (1) {
 		struct ts_sample samp;
@@ -181,15 +182,15 @@ int main(int argc, char **argv)
 			continue;
 
 		for (i = 0; i < NR_BUTTONS; i++)
-			if (button_handle(&buttons [i], samp.x, samp.y, samp.pressure))
+			if (button_handle(&buttons[i], samp.x, samp.y, samp.pressure))
 				switch (i) {
 				case 0:
 					mode = 0;
-					refresh_screen ();
+					refresh_screen();
 					break;
 				case 1:
 					mode = 1;
-					refresh_screen ();
+					refresh_screen();
 					break;
 				case 2:
 					quit_pressed = 1;
@@ -200,7 +201,7 @@ int main(int argc, char **argv)
 
 		if (samp.pressure > 0) {
 			if (mode == 0x80000001)
-				line (x, y, samp.x, samp.y, 2);
+				line(x, y, samp.x, samp.y, 2);
 			x = samp.x;
 			y = samp.y;
 			mode |= 0x80000000;
