@@ -455,7 +455,7 @@ int main(int argc, char **argv)
 		.samp_mt = NULL,
 		.samp_read = NULL,
 		.verbose = 0,
-		.read_fail_count = 0,	
+		.read_fail_count = 0,
 		.read_mt_fail_count = 0,
 		.read_run_count = 0,
 		.read_mt_run_count = 0,
@@ -573,11 +573,19 @@ int main(int argc, char **argv)
 
 	run_tests(&data);
 
+	data.tsconf = fopen(CONFFILE, "a+");
+	fprintf(data.tsconf, "module invert\n");
+	fclose(data.tsconf);
+	printf("======================================================\n");
+	printf("skip -> pthres -> debounce -> median -> dejitter -> lowpass -> invert\n");
+
+	run_tests(&data);
+
 	data.tsconf = fopen(CONFFILE, "a+");
 	fprintf(data.tsconf, "module linear\n");
 	fclose(data.tsconf);
 	printf("======================================================\n");
-	printf("skip -> pthres -> debounce -> median -> dejitter -> lowpass -> linear\n");
+	printf("skip -> pthres -> debounce -> median -> dejitter -> lowpass -> invert -> linear\n");
 
 	run_tests(&data);
 
