@@ -103,6 +103,8 @@
 #define UINPUT_VERSION	2
 #endif
 
+static char *defaultfbdevice = "/dev/fb0";
+
 struct data_t {
 	int fd_uinput;
 	int fd_input;
@@ -118,6 +120,7 @@ struct data_t {
 	int slots;
 	unsigned short uinput_version;
 	short mt_type_a;
+	unsigned short nofb;
 };
 
 static void help(void)
@@ -146,6 +149,7 @@ static void help(void)
 	printf("  -i, --idev          touchscreen's input device\n");
 	printf("  -f, --fbdev         touchscreen's framebuffer device\n");
 	printf("  -s, --slots         override available concurrent touch contacts\n");
+	printf("  -b, --nofb          read screen resolution from the input dev, not the framebuffer device.\n");
 	printf("\n");
 	printf("See the manpage for further details.\n");
 }
@@ -164,7 +168,10 @@ static int send_touch_events(struct data_t *data, struct ts_sample_mt **s,
 		       sizeof(struct input_event) * MAX_CODES_PER_SLOT * max_slots);
 
 		for (i = 0; i < max_slots; i++) {
-			if (s[j][i].pen_down == 1 || s[j][i].pen_down == 0) {
+			if (!(s[j][i].valid & TSLIB_MT_VALID))
+				continue;
+
+			if (s[j][i].pen_down == 1) {
 				data->ev[c].time = s[j][i].tv;
 				data->ev[c].type = EV_KEY;
 				data->ev[c].code = BTN_TOUCH;
@@ -172,9 +179,6 @@ static int send_touch_events(struct data_t *data, struct ts_sample_mt **s,
 				c++;
 			}
 
-			if (!(s[j][i].valid & TSLIB_MT_VALID))
-				continue;
-
 			data->ev[c].time = s[j][i].tv;
 			data->ev[c].type = EV_ABS;
 			data->ev[c].code = ABS_MT_SLOT;
@@ -298,6 +302,15 @@ static int send_touch_events(struct data_t *data, struct ts_sample_mt **s,
 				data->ev[c].value = 0;
 				c++;
 			}
+
+			if (s[j][i].pen_down == 0) {
+				data->ev[c].time = s[j][i].tv;
+				data->ev[c].type = EV_KEY;
+				data->ev[c].code = BTN_TOUCH;
+				data->ev[c].value = s[j][i].pen_down;
+				c++;
+			}
+
 		}
 
 		if (c > 0) {
@@ -321,18 +334,90 @@ static int send_touch_events(struct data_t *data, struct ts_sample_mt **s,
 	return 0;
 }
 
+static int get_abs_max_fb(struct data_t *data, int *max_x, int *max_y)
+{
+	struct fb_var_screeninfo fbinfo;
+
+	if (ioctl(data->fd_fb, FBIOGET_VSCREENINFO, &fbinfo) < 0) {
+		perror("ioctl FBIOGET_VSCREENINFO");
+		return errno;
+	}
+
+	*max_x = fbinfo.xres - 1;
+	*max_y = fbinfo.yres - 1;
+
+	return 0;
+}
+
+static int get_abs_max_input(struct data_t *data, int *max_x, int *max_y)
+{
+	long absbit[BITS_TO_LONGS(ABS_CNT)];
+	struct input_absinfo absinfo;
+	int abs_x_only;
+
+	if (ioctl(data->fd_input, EVIOCGBIT(EV_ABS, sizeof(absbit)), absbit) < 0) {
+		perror("ioctl EVIOCGBIT");
+		return errno;
+	}
+
+	if (!(absbit[BIT_WORD(ABS_MT_POSITION_X)] & BIT_MASK(ABS_MT_POSITION_X)) ||
+	    !(absbit[BIT_WORD(ABS_MT_POSITION_Y)] & BIT_MASK(ABS_MT_POSITION_Y))) {
+		if (!(absbit[BIT_WORD(ABS_X)] & BIT_MASK(ABS_X)) ||
+		    !(absbit[BIT_WORD(ABS_Y)] & BIT_MASK(ABS_Y))) {
+			return errno;
+		} else {
+			abs_x_only = 1;
+		}
+	} else {
+		abs_x_only = 0;
+	}
+
+	if (abs_x_only) {
+		if (ioctl(data->fd_input, EVIOCGABS(ABS_X), &absinfo) < 0) {
+			perror("ioctl EVIOCGABS");
+			return errno;
+		}
+		*max_x = absinfo.maximum;
+
+		if (ioctl(data->fd_input, EVIOCGABS(ABS_Y), &absinfo) < 0) {
+			perror("ioctl EVIOCGABS");
+			return errno;
+		}
+		*max_y = absinfo.maximum;
+	} else {
+		if (ioctl(data->fd_input, EVIOCGABS(ABS_MT_POSITION_X), &absinfo) < 0) {
+			perror("ioctl EVIOCGABS");
+			return errno;
+		}
+		*max_x = absinfo.maximum;
+
+		if (ioctl(data->fd_input, EVIOCGABS(ABS_MT_POSITION_Y), &absinfo) < 0) {
+			perror("ioctl EVIOCGABS");
+			return errno;
+		}
+		*max_y = absinfo.maximum;
+	}
+
+	return 0;
+}
+
 static int setup_uinput(struct data_t *data, int *max_slots)
 {
 	struct uinput_user_dev uidev;
 	unsigned long bit[EV_MAX][NBITS(KEY_MAX)];
 	int i, j;
 	struct input_absinfo absinfo;
-	struct fb_var_screeninfo fbinfo;
+	int max_x = 0;
+	int max_y = 0;
+	int ret;
 
-	if (ioctl(data->fd_fb, FBIOGET_VSCREENINFO, &fbinfo) < 0) {
-		perror("ioctl FBIOGET_VSCREENINFO");
-		goto err;
-	}
+	if (data->nofb)
+		ret = get_abs_max_input(data, &max_x, &max_y);
+	else
+		ret = get_abs_max_fb(data, &max_x, &max_y);
+
+	if (ret)
+		return ret;
 
 	data->fd_uinput = open("/dev/uinput", O_WRONLY | O_NONBLOCK);
 	if (data->fd_uinput == -1) {
@@ -392,27 +477,23 @@ static int setup_uinput(struct data_t *data, int *max_slots)
 
 						if (j == ABS_X) {
 							uidev.absmin[ABS_X] = 0;
-							uidev.absmax[ABS_X] = fbinfo.xres - 1;
+							uidev.absmax[ABS_X] = max_x;
 						} else if (j == ABS_Y) {
 							uidev.absmin[ABS_Y] = 0;
-							uidev.absmax[ABS_Y] = fbinfo.yres - 1;
+							uidev.absmax[ABS_Y] = max_y;
 						} else if (j == ABS_MT_POSITION_X) {
 							uidev.absmin[ABS_MT_POSITION_X] = 0;
-							uidev.absmax[ABS_MT_POSITION_X] = fbinfo.xres - 1;
+							uidev.absmax[ABS_MT_POSITION_X] = max_x;
 						} else if (j == ABS_MT_POSITION_Y) {
 							uidev.absmin[ABS_MT_POSITION_Y] = 0;
-							uidev.absmax[ABS_MT_POSITION_Y] = fbinfo.yres - 1;
+							uidev.absmax[ABS_MT_POSITION_Y] = max_y;
 						} else {
 							uidev.absmin[j] = absinfo.minimum;
 							uidev.absmax[j] = absinfo.maximum;
 						}
 
-						if (j == ABS_MT_SLOT) {
+						if (j == ABS_MT_SLOT)
 							*max_slots = absinfo.maximum + 1 - absinfo.minimum;
-						}
-					} else if (i == EV_SYN) {
-						if (j == SYN_MT_REPORT)
-							data->mt_type_a = 1;
 					}
 				}
 			}
@@ -516,7 +597,8 @@ static void cleanup(struct data_t *data)
 }
 
 /* directly from libevdev (LGPL) */
-static int is_event_device(const struct dirent *dent) {
+static int is_event_device(const struct dirent *dent)
+{
 	return strncmp("event", dent->d_name, 5) == 0;
 }
 
@@ -544,135 +626,6 @@ static char *fetch_device_node(const char *path)
 	return devnode;
 }
 
-/* --- start src/ts_setup.c plus reporting the chosen input device --- */
-
-#define DEV_INPUT_EVENT "/dev/input"
-#define EVENT_DEV_NAME "event"
-
-static char* scan_devices(void)
-{
-	struct dirent **namelist;
-	int i, ndev;
-	char *filename = NULL;
-	int have_touchscreen = 0;
-	long propbit[BITS_TO_LONGS(INPUT_PROP_MAX)] = {0};
-
-	ndev = scandir(DEV_INPUT_EVENT, &namelist, is_event_device, alphasort);
-	if (ndev <= 0)
-		return NULL;
-
-	for (i = 0; i < ndev; i++) {
-		char fname[64];
-		int fd = -1;
-
-		snprintf(fname, sizeof(fname),
-			 "%s/%s", DEV_INPUT_EVENT, namelist[i]->d_name);
-		fd = open(fname, O_RDONLY);
-		if (fd < 0)
-			continue;
-
-		if ((ioctl(fd, EVIOCGPROP(sizeof(propbit)), propbit) < 0) ||
-			!(propbit[BIT_WORD(INPUT_PROP_DIRECT)] &
-				  BIT_MASK(INPUT_PROP_DIRECT)) ) {
-			close(fd);
-			continue;
-		} else {
-			close(fd);
-			have_touchscreen = 1;
-		}
-
-		free(namelist[i]);
-
-                if (have_touchscreen) {
-			filename = malloc(strlen(DEV_INPUT_EVENT) +
-					  strlen(EVENT_DEV_NAME) +
-					  3);
-			if (!filename)
-				return NULL;
-
-	                sprintf(filename, "%s/%s%d",
-				DEV_INPUT_EVENT, EVENT_DEV_NAME,
-				i);
-		}
-
-		return filename;
-	}
-
-	return NULL;
-}
-
-static char *ts_name_default[] = {
-		"/dev/input/ts",
-		"/dev/input/touchscreen",
-		"/dev/touchscreen/ucb1x00",
-		NULL
-};
-
-#define EVENTNAME_LEN 15
-
-static struct tsdev *ts_setup_ext(char *dev_name, int nonblock,
-				  char **dev_input_event)
-{
-	char **defname;
-	struct tsdev *ts = NULL;
-	char *found = NULL;
-	int scanned = 0;
-
-	*dev_input_event = malloc(strlen(DEV_INPUT_EVENT) + EVENTNAME_LEN);
-	if (!*dev_input_event)
-		return NULL;
-
-	dev_name = dev_name ? dev_name : getenv("TSLIB_TSDEVICE");
-
-	if (dev_name != NULL) {
-		found = dev_name;
-		goto open;
-	}
-
-	defname = &ts_name_default[0];
-	while (*defname != NULL) {
-		ts = ts_open(*defname, nonblock);
-		if (ts != NULL) {
-			found = *defname;
-			goto opened;
-		}
-
-		++defname;
-	}
-
-	found = scan_devices();
-	if (!found) {
-		return NULL;
-	} else {
-		scanned = 1;
-		goto open;
-	}
-
-open:
-	ts = ts_open(found, nonblock);
-opened:
-	if (strlen(found) >= strlen(DEV_INPUT_EVENT) + EVENTNAME_LEN) {
-		if (ts)
-			ts_close(ts);
-
-		return NULL;
-	}
-
-	sprintf(*dev_input_event, "%s", found);
-
-	if (scanned)
-		free(found);
-
-	/* if detected try to configure it */
-	if (ts && ts_config(ts) != 0) {
-		ts_close(ts);
-		return NULL;
-	}
-
-	return ts;
-}
-/* --- end src/ts_setup.c ---*/
-
 int main(int argc, char **argv)
 {
 	struct data_t data = {
@@ -688,6 +641,7 @@ int main(int argc, char **argv)
 		.slots = 1,
 		.mt_type_a = 0,
 		.verbose_daemon = 0,
+		.nofb = 0,
 	};
 	int i, j;
 	unsigned short run_daemon = 0;
@@ -705,10 +659,11 @@ int main(int argc, char **argv)
 			{ "idev",         required_argument, NULL, 'i' },
 			{ "fbdev",        required_argument, NULL, 'f' },
 			{ "slots",        required_argument, NULL, 's' },
+			{ "nofb",         no_argument,       NULL, 'b' },
 		};
 
 		int option_index = 0;
-		int c = getopt_long(argc, argv, "dhn:f:i:vs:", long_options,
+		int c = getopt_long(argc, argv, "dhn:f:i:vs:b", long_options,
 				    &option_index);
 
 		if (c == -1)
@@ -728,6 +683,10 @@ int main(int argc, char **argv)
 			data.verbose = 1;
 			break;
 
+		case 'b':
+			data.nofb = 1;
+			break;
+
 		case 'd':
 			run_daemon = 1;
 			break;
@@ -751,6 +710,7 @@ int main(int argc, char **argv)
 
 		if (errno) {
 			char str[9];
+
 			sprintf(str, "option ?");
 			str[7] = c & 0xff;
 			perror(str);
@@ -758,7 +718,8 @@ int main(int argc, char **argv)
 	}
 
 	/* if we run as a daemon, we don't print all debug output. we print
-	 * the input device node before returning. */
+	 * the input device node before returning.
+	 */
 	if (data.verbose && run_daemon) {
 		data.verbose = 0;
 		data.verbose_daemon = 1;
@@ -782,32 +743,30 @@ int main(int argc, char **argv)
 		sprintf(data.uinput_name, DEFAULT_UINPUT_NAME);
 	}
 
-	if (!data.fb_name) {
-		if (getenv("TSLIB_FBDEVICE")) {
-			data.fb_name = getenv("TSLIB_FBDEVICE");
-		} else {
-			fprintf(stderr, RED DEFAULT_UINPUT_NAME
-				": no framebuffer device specified"
-				RESET "\n");
+	if (!data.nofb) {
+		if (!data.fb_name) {
+			if (getenv("TSLIB_FBDEVICE"))
+				data.fb_name = getenv("TSLIB_FBDEVICE");
+			else
+				data.fb_name = defaultfbdevice;
+		}
+
+		data.fd_fb = open(data.fb_name, O_RDWR);
+		if (data.fd_fb == -1) {
+			perror("open");
 			goto out;
 		}
-	}
 
-	data.fd_fb = open(data.fb_name, O_RDWR);
-	if (data.fd_fb == -1) {
-		perror("open");
-		goto out;
+		if (data.verbose)
+			printf(DEFAULT_UINPUT_NAME ": using framebuffer device "
+			       GREEN "%s" RESET "\n",
+			       data.fb_name);
 	}
 
-	if (data.verbose)
-		printf(DEFAULT_UINPUT_NAME ": using framebuffer device "
-		       GREEN "%s" RESET "\n",
-		       getenv("TSLIB_FBDEVICE"));
-
 	/* non-blocking for one read in order to verify reading and fail before forking */
-	data.ts = ts_setup_ext(data.input_name, 1, &dev_input_name);
-	if (!data.ts || !dev_input_name) {
-		perror("ts_setup_ext");
+	data.ts = ts_setup(data.input_name, 1);
+	if (!data.ts) {
+		perror("ts_setup");
 		goto out;
 	}
 
@@ -833,12 +792,16 @@ int main(int argc, char **argv)
 	free(testsample_p);
 
 	/* blocking setup for production run */
-	data.ts = ts_setup_ext(data.input_name, 0, &dev_input_name);
-	if (!data.ts || !dev_input_name) {
-		perror("ts_setup_ext");
+	data.ts = ts_setup(data.input_name, 0);
+	if (!data.ts) {
+		perror("ts_setup");
 		goto out;
 	}
 
+	dev_input_name = ts_get_eventpath(data.ts);
+	if (!dev_input_name)
+		goto out;
+
 	data.fd_input = open(dev_input_name, O_RDWR);
 	if (data.fd_input == -1) {
 		perror("open");
@@ -907,33 +870,33 @@ int main(int argc, char **argv)
 	}
 
 	if (run_daemon) {
-		#if UINPUT_VERSION >= 4
-			char name[64];
-			int ret = ioctl(data.fd_uinput,
-					UI_GET_SYSNAME(sizeof(name)),
-					name);
-			if (ret >= 0) {
-				if (data.verbose_daemon) {
-					char buf[sizeof(SYS_INPUT_DIR) + sizeof(name)] = SYS_INPUT_DIR;
-					char *devnode;
+	#if UINPUT_VERSION >= 4
+		char name[64];
+		int ret = ioctl(data.fd_uinput,
+				UI_GET_SYSNAME(sizeof(name)),
+				name);
+		if (ret >= 0) {
+			if (data.verbose_daemon) {
+				char buf[sizeof(SYS_INPUT_DIR) + sizeof(name)] = SYS_INPUT_DIR;
+				char *devnode;
 
-					snprintf(&buf[strlen(SYS_INPUT_DIR)], sizeof(name), "%s", name);
-					devnode = fetch_device_node(buf);
-					if (devnode)
-						fprintf(stdout, "%s\n", devnode);
-				} else {
-					fprintf(stdout, "%s\n", name);
-				}
-
-				fflush(stdout);
+				snprintf(&buf[strlen(SYS_INPUT_DIR)], sizeof(name), "%s", name);
+				devnode = fetch_device_node(buf);
+				if (devnode)
+					fprintf(stdout, "%s\n", devnode);
 			} else {
-				perror("ioctl UI_GET_SYSNAME");
-				goto out;
+				fprintf(stdout, "%s\n", name);
 			}
-		#else
-			fprintf(stderr, DEFAULT_UINPUT_NAME
-			": See the kernel log for the device number\n");
-		#endif
+
+			fflush(stdout);
+		} else {
+			perror("ioctl UI_GET_SYSNAME");
+			goto out;
+		}
+	#else
+		fprintf(stderr, DEFAULT_UINPUT_NAME
+		": See the kernel log for the device number\n");
+	#endif
 		if (daemon(0, 0) == -1) {
 			perror("error starting daemon");
 			goto out;
